"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const mocha_1 = require("mocha");
const removeRegex = require("../remove_regexes");
const findAttr = require("../find_attributes");
const createAttr = require("../create_attributes");
mocha_1.suite('Plugin Tests', function () {
    //  //: JS, TS, C/ C++/ C#, Java, GO, Rust, Scala, Swift, J#, Dlang single line comment
    const commentChar1 = { frontComment: '//', endComment: '' };
    // #: Python, Ruby, powershell, Julia, R, prolog, Crystal, Dockerfile, Diff single line comment
    const commentChar2 = { frontComment: '#', endComment: '' };
    // /* */: C++, CSS single line comment 
    const commentChar3 = { frontComment: '--', endComment: '' };
    // <!-- -->: HTML, PHP, Markdown, Vue single line comment
    const commentChar4 = { frontComment: '%', endComment: '' };
    // --: SQL, Haskell single line comment
    const commentChar5 = { frontComment: ';', endComment: '' };
    // %: LaTex single line comment
    const commentChar6 = { frontComment: '/*', endComment: '*/' };
    // ;: clojure single line comment
    const commentChar7 = { frontComment: '<!--', endComment: '-->' };
    /* eslint-disable prefer-const*/
    const commentCharArr = [commentChar1, commentChar2, commentChar3, commentChar4, commentChar5,
        commentChar6, commentChar7];
    // Global function used for #findNumFlagVal and #removeNumFlag
    function getRandomInt(max) {
        return Math.floor(Math.random() * Math.floor(max));
    }
    mocha_1.suite('Find comment regex in string -> #findCommentChar', function () {
        mocha_1.test('String w/o comment regex', function () {
            // error example
            const err = 'Invalid line comment. Please use single line comment for howdoi.';
            chai_1.expect(function () {
                findAttr.findCommentChar('howdoi query');
            }).to.throw(err);
        });
        mocha_1.test('Comment regex test (w/ space): //, #, --, %, ;, /* */, <!-- -->', function () {
            for (let commentChar of commentCharArr) {
                let commentedQuery = commentChar.frontComment + ' howdoi query ' + commentChar.endComment;
                chai_1.assert.deepEqual(findAttr.findCommentChar(commentedQuery), commentChar);
            }
        });
        mocha_1.test('Comment regex test (w/o space): //, #, --, %, ;, /* */, <!-- -->', function () {
            for (let commentChar of commentCharArr) {
                let commentedQuery = commentChar.frontComment + 'howdoi query' + commentChar.endComment;
                chai_1.assert.deepEqual(findAttr.findCommentChar(commentedQuery), commentChar);
            }
        });
    });
    mocha_1.suite('Find the Num Flag value from the user command -> #findNumFlagVal', function () {
        mocha_1.test('error examples', function () {
            const err = 'Invalid num flag value';
            chai_1.expect(function () {
                findAttr.findNumFlagVal('query -n');
            }).to.throw(err);
            chai_1.expect(function () {
                findAttr.findNumFlagVal('query -nzl');
            }).to.throw(err);
        });
        mocha_1.test('testing default num 3', function () {
            chai_1.assert.equal(findAttr.findNumFlagVal('query -n3'), 3);
            chai_1.assert.equal(findAttr.findNumFlagVal('query -n 3'), 3);
        });
        mocha_1.test('testing non-default numbers', function () {
            const maxNum = 25;
            for (let i = 0; i < maxNum; i++) {
                const randomNum = getRandomInt(maxNum);
                const query1 = 'query -n' + String(randomNum);
                const query2 = 'query -n ' + String(randomNum);
                if (randomNum === 0) {
                    const err = 'Invalid num flag value';
                    chai_1.expect(function () {
                        findAttr.findNumFlagVal(query1);
                    }).to.throw(err);
                }
                else {
                    chai_1.assert.equal(findAttr.findNumFlagVal(query1), randomNum);
                    chai_1.assert.equal(findAttr.findNumFlagVal(query2), randomNum);
                }
            }
        });
    });
    mocha_1.suite('Removal of comment character from user command -> #removeCommentChar', function () {
        mocha_1.test('Removal of front and front/back comment char (w/ space): //, #, --, %, ;, /* */, <!-- -->', function () {
            for (let commentChar of commentCharArr) {
                let commentedQuery = commentChar.frontComment + ' howdoi query ' + commentChar.endComment;
                chai_1.assert.equal(removeRegex.removeCommentChar(commentedQuery, commentChar), 'howdoi query');
            }
        });
        mocha_1.test('Removal of front and front/back comment char (w/o space): //, #, --, %, ;, /* */, <!-- -->', function () {
            for (let commentChar of commentCharArr) {
                let commentedQuery = commentChar.frontComment + 'howdoi query' + commentChar.endComment;
                chai_1.assert.equal(removeRegex.removeCommentChar(commentedQuery, commentChar), 'howdoi query');
            }
        });
    });
    mocha_1.suite('Removal of howdoi prefix test -> #removeHowdoiPrefix', function () {
        mocha_1.test('Normal Query', function () {
            // Normal Query
            chai_1.assert.equal(removeRegex.removeHowdoiPrefix('howdoi query'), 'query');
        });
        mocha_1.test('Query with whitespace', function () {
            // Query with whitespace
            chai_1.assert.equal(removeRegex.removeHowdoiPrefix(' howdoi query '), 'query');
        });
        mocha_1.test('Query without howdoi prefix', function () {
            // Query without howdoi prefix
            const err = 'Place "howdoi" in front of query';
            chai_1.expect(function () {
                removeRegex.removeHowdoiPrefix('query');
            }).to.throw(err);
        });
        mocha_1.test('Query without howdoi prefix and whitespace', function () {
            // Query without howdoi prefix and whitespace
            const err = 'Place "howdoi" in front of query';
            chai_1.expect(function () {
                removeRegex.removeHowdoiPrefix(' query ');
            }).to.throw(err);
        });
    });
    mocha_1.suite('Remove the Num Flag and value from the user command -> #removeNumFlag', function () {
        mocha_1.test('testing default num 3', function () {
            chai_1.assert.equal(removeRegex.removeNumFlag('query -n3'), 'query');
            chai_1.assert.equal(removeRegex.removeNumFlag('query -n 3'), 'query');
        });
        mocha_1.test('testing non-default numbers', function () {
            const maxNum = 25;
            for (let i = 0; i < maxNum; i++) {
                const randomNum = getRandomInt(maxNum);
                const query1 = 'query -n' + String(randomNum);
                const query2 = 'query -n ' + String(randomNum);
                chai_1.assert.equal(removeRegex.removeNumFlag(query1), 'query');
                chai_1.assert.equal(removeRegex.removeNumFlag(query2), 'query');
            }
        });
    });
    mocha_1.suite('Create comment character to a string -> #createComment', function () {
        mocha_1.test('Creare comment with front & front/back char to string: //, #, --, %, ;, /* */, <!-- -->', function () {
            let testString = '';
            for (let commentChar of commentCharArr) {
                if (commentChar.frontComment && (commentChar.endComment !== '')) {
                    testString = commentChar.frontComment + ' howdoi query ' + commentChar.endComment;
                }
                else {
                    testString = commentChar.frontComment + ' howdoi query';
                }
                chai_1.assert.equal(createAttr.createComment('howdoi query', commentChar), testString);
            }
        });
    });
});
//# sourceMappingURL=plugin.test.js.map